# SolarEnergy #

A Python module do simple modelling in the field of solar energy.  The code is being developped by Marc van
der Sluys of the department of Sustainable energy of the HAN University of Applied Sciences in Arnhem, the
Netherlands.


## Installation ##

This package can be installed using `pip install solarenergy`.  This should automatically install the dependency
packages `sys`, `datetime`, `pytz`, `numpy` and `soltrack` if they haven't been installed already.
If you are installing by hand, ensure that these packages are installed as well.


## SolarEnergy pages ##

* [Pypi](https://pypi.org/project/solarenergy/): SolarEnergy Python package
* [GitHub](https://github.com/MarcvdSluys/SolarEnergy): SolarEnergy source code


## Author and licence ##

* Author: Marc van der Sluys
* Contact: http://han.vandersluys.nl/en/
* Licence: [GPLv3+](https://www.gnu.org/licenses/gpl.html)


## References ##

* This Python code is adapted from the Fortran implementation in
  [libTheSky](http://libthesky.sourceforge.net/), which contains many references.
* [Celestial mechanics in a nutshell (CMiaNS)](https://cmians.sourceforge.io/)
